==> MotIV_1.1.3.tar.gz: MotIV/man/seqLogo.Rd <==
\name{seqLogo}
\alias{seqLogo}
\title{Plot a sequence logo for a given position weight matrix}
\description{
  This function takes the 4xW position weight matrix of a DNA sequence
  motif and plots the corresponding sequence logo. 
}
\usage{
  seqLogo(pwm, ic.scale=TRUE, xaxis=TRUE, yaxis=TRUE, xfontsize=15, yfontsize=15,vmargins=0,hmargins=0,size=1)
}
\arguments{
	\item{pwm}{\code{numeric} The 4xW position weight matrix.}
	\item{ic.scale}{\code{logical} If TRUE, the height of each column is proportional to its information content. Otherwise, all columns have the same height.}
	\item{xaxis}{\code{logical} If TRUE, an X-axis will be plotted.}
	\item{yaxis}{\code{logical} If TRUE, a Y-axis will be plotted.}
	\item{xfontsize}{\code{numeric} Font size to be used for the X-axis.}
	\item{yfontsize}{\code{numeric} Font size to be used for the Y-axis.} 
	\item{vmargins}{\code{numeric} Vertical margins.} 
	\item{hmargins}{\code{numeric} Horizontal margins.} 
	\item{size}{\code{numeric} Graphic size.} 
}
\details{
  Within each column, the height
  of a given letter is proportional to its frequency at that position.
  If ic.scale is TRUE, the height of each column in the plot indicates
  the information
  content at that position of the motif. Otherwise, the height of all
  columns are identical.
}
\value{
  None.
}
\author{Oliver Bembom, \email{bembom@berkeley.edu}}

\examples{
#mFile <- system.file("Exfiles/pwm1", package="seqLogo")
#m <- read.table(mFile)
#pwm <- makePWM(m)
#seqLogo(pwm)
}
\keyword{misc}

==> MotIV_1.6.0.tar.gz: MotIV/man/seqLogo.Rd <==
\name{seqLogo}
\alias{seqLogo}
\title{Plot a sequence logo for a given position weight matrix}
\description{
  This function takes the 4xW position weight matrix of a DNA sequence
  motif and plots the corresponding sequence logo. 
}
\usage{
  seqLogo(pwm, ic.scale=TRUE, xaxis=TRUE, yaxis=TRUE, xfontsize=15, yfontsize=15,vmargins=c(0,0),hmargins=c(0,0),size=1, trim=0)
}
\arguments{
	\item{pwm}{\code{numeric} The 4xW position weight matrix.}
	\item{ic.scale}{\code{logical} If TRUE, the height of each column is proportional to its information content. Otherwise, all columns have the same height.}
	\item{xaxis}{\code{logical} If TRUE, an X-axis will be plotted.}
	\item{yaxis}{\code{logical} If TRUE, a Y-axis will be plotted.}
	\item{xfontsize}{\code{numeric} Font size to be used for the X-axis.}
	\item{yfontsize}{\code{numeric} Font size to be used for the Y-axis.} 
	\item{vmargins}{\code{numeric} Vertical margins.} 
	\item{hmargins}{\code{numeric} Horizontal margins.} 
	\item{size}{\code{numeric} Graphic size.} 
	\item{trim}{\code{numeric} Only print letters with information content superior to a treshold given by \code{trim}}
}
\details{
  Within each column, the height
  of a given letter is proportional to its frequency at that position.
  If ic.scale is TRUE, the height of each column in the plot indicates
  the information
  content at that position of the motif. Otherwise, the height of all
  columns are identical.
}
\value{
  None.
}
\author{Oliver Bembom, \email{bembom@berkeley.edu}}

\examples{
#mFile <- system.file("Exfiles/pwm1", package="seqLogo")
#m <- read.table(mFile)
#pwm <- makePWM(m)
#seqLogo(pwm)
}
\keyword{misc}
